Changelog
=========


0.3.12 (2022-01-20)
-------------------

- Add cookies consent viewlet in minisite mode (in Diazo rules)
  [laulaz]


0.3.11 (2019-07-09)
-------------------

- Improve CSS media queries sizes
  [laulaz]


0.3.10 (2019-04-10)
-------------------

- Fix CSS
  [osnickers]

- Fix minisite dropdown menu which was hidden
  [laulaz]


0.3.9 (2019-03-04)
------------------

- Add dropdown menu for mini site : WEB-2928
  [mgennart]


0.3.8 (2019-03-04)
------------------

- Add portal-languageselector in action.
  [mgennart]


0.3.7 (2019-01-08)
------------------

- Add rules for top slider : WEB-2407
  [mgennart]

- Add class for collapsable minisite menu
  [mgennart]
  
- Use fragment to get "Search" translation
  [laulaz]


0.3.6 (2018-09-07)
------------------

- Change rules for hidden-search.
  [mgennart]

0.3.5 (2018-08-27)
------------------

- Add uninstall profile
  [laulaz]

- Change rules to use new options for search position : #21303
  [laulaz]

 
0.3.4 (2018-01-09)
------------------

- Add top-menu-actions in top-actions. 
  [mgennart]

0.3.3 (2017-10-12)
------------------

- change manifest.
  [mgennart]


0.3.2 (2017-07-17)
------------------

- Remove unused skin.
  [bsuttor]

- Add new annuaire.xml rules coming from cpskin.theme : #17751
  [laulaz]

- Add missing rules for right actions panel : #17748
  [laulaz]


0.3.1 (2017-06-15)
------------------

- Add missing dependency on cpskin.diazotheme.dream
  [laulaz]

- Fix LESS styles inheritance from cpskin.diazotheme.dream : #17714
  [laulaz]


0.3 (2017-05-29)
----------------

- Ensure cpskin.theme is migrated to LESS before migrating this theme
  [laulaz]

- Split media queries into different LESS files
  [laulaz]

- Complete migration to LESS
  [laulaz]

- Reorder theme parameters (harmonization)
  [laulaz]

- Buildout harmonization
  [laulaz]


0.2 (2017-02-28)
----------------

- Add the rules for the right portlets of cpskin.dream.
  [mgennart]


0.1 (2017-01-25)
----------------

- Initial release.
